==> zio-aws-macie2_2.12-5.17.201.1-sources.jar: zio/aws/macie2/model/ListCustomDataIdentifiersResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListCustomDataIdentifiersResponse(
    items: Optional[
      Iterable[zio.aws.macie2.model.CustomDataIdentifierSummary]
    ] = Optional.Absent,
    nextToken: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse = {
    import ListCustomDataIdentifiersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.ListCustomDataIdentifiersResponse.ReadOnly =
    zio.aws.macie2.model.ListCustomDataIdentifiersResponse.wrap(buildAwsValue())
}
object ListCustomDataIdentifiersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListCustomDataIdentifiersResponse =
      zio.aws.macie2.model.ListCustomDataIdentifiersResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Optional[
      List[zio.aws.macie2.model.CustomDataIdentifierSummary.ReadOnly]
    ]
    def nextToken: Optional[__string]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.CustomDataIdentifierSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
  ) extends zio.aws.macie2.model.ListCustomDataIdentifiersResponse.ReadOnly {
    override val items: Optional[
      List[zio.aws.macie2.model.CustomDataIdentifierSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.CustomDataIdentifierSummary.wrap(item)
        }.toList
      )
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
  ): zio.aws.macie2.model.ListCustomDataIdentifiersResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_3-5.17.116.1-sources.jar: zio/aws/macie2/model/ListCustomDataIdentifiersResponse.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ListCustomDataIdentifiersResponse(
    items: Option[Iterable[zio.aws.macie2.model.CustomDataIdentifierSummary]] =
      None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse = {
    import ListCustomDataIdentifiersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.ListCustomDataIdentifiersResponse.ReadOnly =
    zio.aws.macie2.model.ListCustomDataIdentifiersResponse.wrap(buildAwsValue())
}
object ListCustomDataIdentifiersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListCustomDataIdentifiersResponse =
      zio.aws.macie2.model.ListCustomDataIdentifiersResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[
      List[zio.aws.macie2.model.CustomDataIdentifierSummary.ReadOnly]
    ]
    def nextToken: Option[__string]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.macie2.model.CustomDataIdentifierSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
  ) extends zio.aws.macie2.model.ListCustomDataIdentifiersResponse.ReadOnly {
    override val items: Option[
      List[zio.aws.macie2.model.CustomDataIdentifierSummary.ReadOnly]
    ] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.CustomDataIdentifierSummary.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListCustomDataIdentifiersResponse
  ): zio.aws.macie2.model.ListCustomDataIdentifiersResponse.ReadOnly =
    new Wrapper(impl)
}
